#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-ASquHeQTBX16oQxCWzD5TF
key:                  pointed-5.0.5-ASquHeQTBX16oQxCWzD5TF
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  8e5e3469dc7297b78218f088572f3a4a
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-ASquHeQTBX16oQxCWzD5TF
depends:
    base-4.18.2.1 comonad-5.0.10-B889lQhRO1yL1ChUrh086d
    containers-0.6.7 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    hashable-1.4.7.0-DeckboSXRoV2uaWXBDn9RA
    kan-extensions-5.2.8-GrYgeMUMYYkDZzGzJRXGc8
    semigroupoids-6.0.2-2nn8TB8Oa649Qe5UBflX3R stm-2.5.1.0
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

